@@ -47,7 +47,7 @@ class LintProblem(object):
     @property
     def message(self):
         if self.rule is not None:
-            return '%s (%s)' % (self.desc, self.rule)
+            return '{} ({})'.format(self.desc, self.rule)
         return self.desc
 
     def __eq__(self, other):
@@ -75,10 +75,10 @@ def get_cosmetic_problems(buffer, conf, filepath):
     for rule in token_rules:
         context[rule.ID] = {}
 
-    class DisableDirective():
+    class DisableDirective:
         def __init__(self):
             self.rules = set()
-            self.all_rules = set([r.ID for r in rules])
+            self.all_rules = {r.ID for r in rules}
 
         def process_comment(self, comment):
             try:
@@ -87,7 +87,8 @@ def get_cosmetic_problems(buffer, conf, filepath):
                 return  # this certainly wasn't a yamllint directive comment
 
             if re.match(r'^# yamllint disable( rule:\S+)*\s*$', comment):
-                rules = [item[5:] for item in comment[18:].split(' ')][1:]
+                items = comment[18:].rstrip().split(' ')
+                rules = [item[5:] for item in items][1:]
                 if len(rules) == 0:
                     self.rules = self.all_rules.copy()
                 else:
@@ -96,7 +97,8 @@ def get_cosmetic_problems(buffer, conf, filepath):
                             self.rules.add(id)
 
             elif re.match(r'^# yamllint enable( rule:\S+)*\s*$', comment):
-                rules = [item[5:] for item in comment[17:].split(' ')][1:]
+                items = comment[17:].rstrip().split(' ')
+                rules = [item[5:] for item in items][1:]
                 if len(rules) == 0:
                     self.rules.clear()
                 else:
@@ -114,7 +116,8 @@ def get_cosmetic_problems(buffer, conf, filepath):
                 return  # this certainly wasn't a yamllint directive comment
 
             if re.match(r'^# yamllint disable-line( rule:\S+)*\s*$', comment):
-                rules = [item[5:] for item in comment[23:].split(' ')][1:]
+                items = comment[23:].rstrip().split(' ')
+                rules = [item[5:] for item in items][1:]
                 if len(rules) == 0:
                     self.rules = self.all_rules.copy()
                 else:
@@ -180,7 +183,7 @@ def get_syntax_error(buffer):
     except yaml.error.MarkedYAMLError as e:
         problem = LintProblem(e.problem_mark.line + 1,
                               e.problem_mark.column + 1,
-                              'syntax error: ' + e.problem)
+                              'syntax error: ' + e.problem + ' (syntax)')
         problem.level = 'error'
         return problem
 
@@ -189,6 +192,10 @@ def _run(buffer, conf, filepath):
     assert hasattr(buffer, '__getitem__'), \
         '_run() argument must be a buffer, not a stream'
 
+    first_line = next(parser.line_generator(buffer)).content
+    if re.match(r'^#\s*yamllint disable-file\s*$', first_line):
+        return
+
     # If the document contains a syntax error, save it and yield it at the
     # right line
     syntax_error = get_syntax_error(buffer)
@@ -226,7 +233,7 @@ def run(input, conf, filepath=None):
     if conf.is_file_ignored(filepath):
         return ()
 
-    if type(input) in (type(b''), type(u'')):  # compat with Python 2 & 3
+    if isinstance(input, (bytes, str)):
         return _run(input, conf, filepath)
     elif hasattr(input, 'read'):  # Python 2's file or Python 3's io.IOBase
         # We need to have everything in memory to parse correctly
